@@ -1,6 +1,5 @@
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
 import numpy as np
+
 from ._overlap import _compute_overlap
 
 __all__ = ['compute_overlap']
@@ -27,9 +26,9 @@ def compute_overlap(ilon, ilat, olon, olat):
     area_ratio : np.ndarray of length N
         TODO
     """
-    ilon = np.asarray(ilon, dtype=np.float64)
-    ilat = np.asarray(ilat, dtype=np.float64)
-    olon = np.asarray(olon, dtype=np.float64)
-    olat = np.asarray(olat, dtype=np.float64)
+    ilon = np.ascontiguousarray(ilon, dtype=np.float64)
+    ilat = np.ascontiguousarray(ilat, dtype=np.float64)
+    olon = np.ascontiguousarray(olon, dtype=np.float64)
+    olat = np.ascontiguousarray(olat, dtype=np.float64)
 
     return _compute_overlap(ilon, ilat, olon, olat)
