@@ -1,10 +1,9 @@
 import numpy as np
-
 import pytest
-from astropy.coordinates import FK5, Galactic, ICRS
 from astropy.io import fits
-from astropy.wcs import WCS
 from astropy.utils.data import get_pkg_data_filename
+from astropy.wcs import WCS
+from astropy.nddata import NDData
 
 from ..utils import parse_input_data, parse_output_projection
 
@@ -13,7 +12,7 @@ def test_parse_input_data(tmpdir):
 
     header = fits.Header.fromtextfile(get_pkg_data_filename('data/gc_ga.hdr'))
 
-    data = np.arange(200).reshape((10,20))
+    data = np.arange(200).reshape((10, 20))
 
     hdu = fits.ImageHDU(data)
 
@@ -27,7 +26,8 @@ def test_parse_input_data(tmpdir):
 
     with pytest.raises(ValueError) as exc:
         array, coordinate_system = parse_input_data(filename)
-    assert exc.value.args[0] == "More than one HDU is present, please specify HDU to use with ``hdu_in=`` option"
+    assert exc.value.args[0] == ("More than one HDU is present, please specify "
+                                 "HDU to use with ``hdu_in=`` option")
 
     array, coordinate_system = parse_input_data(filename, hdu_in=1)
     np.testing.assert_allclose(array, data)
@@ -41,11 +41,16 @@ def test_parse_input_data(tmpdir):
     array, coordinate_system = parse_input_data((data, wcs))
     np.testing.assert_allclose(array, data)
 
+    ndd = NDData(data, wcs=wcs)
+    array, coordinate_system = parse_input_data(ndd)
+    np.testing.assert_allclose(array, data)
+    assert coordinate_system is wcs
+
     # Invalid
     with pytest.raises(TypeError) as exc:
         parse_input_data(data)
-    assert exc.value.args[0] == "input_data should either be an HDU object or a tuple of (array, WCS) or (array, Header)"
-
+    assert exc.value.args[0] == ("input_data should either be an HDU object or "
+                                 "a tuple of (array, WCS) or (array, Header)")
 
 
 def test_parse_output_projection(tmpdir):
@@ -57,7 +62,8 @@ def test_parse_output_projection(tmpdir):
 
     with pytest.raises(ValueError) as exc:
         parse_output_projection(header)
-    assert exc.value.args[0] == "Need to specify shape since output header does not contain complete shape information"
+    assert exc.value.args[0] == ("Need to specify shape since output header "
+                                 "does not contain complete shape information")
 
     parse_output_projection(header, shape_out=(200, 200))
 
@@ -71,6 +77,7 @@ def test_parse_output_projection(tmpdir):
 
     with pytest.raises(ValueError) as exc:
         parse_output_projection(wcs)
-    assert exc.value.args[0] == "Need to specify shape when specifying output_projection as WCS object"
+    assert exc.value.args[0] == ("Need to specify shape_out when specifying "
+                                 "output_projection as WCS object")
 
     parse_output_projection(wcs, shape_out=(200, 200))
